@@ -66,7 +66,7 @@ gs_ls <- function(regex = NULL, ..., verbose = TRUE) {
 
   # only calling spreadsheets feed from here, so hardwiring url
   the_url <- "https://spreadsheets.google.com/feeds/spreadsheets/private/full"
-  req <- httr::GET(the_url, google_token()) %>%
+  req <- rGET(the_url, google_token()) %>%
     httr::stop_for_status()
   rc <- content_as_xml_UTF8(req)
 
