@@ -107,9 +107,9 @@ gs_read_listfeed <- function(ss, ws = 1,
   the_query <- list(reverse = reverse, orderby = orderby, sq = sq)
   the_url <- httr::modify_url(this_ws$listfeed, query = the_query)
   req <-
-    httr::GET(the_url,
-              omit_token_if(grepl("public", the_url)),
-              if (interactive() && ddd$progress && verbose) httr::progress() else NULL) %>%
+    rGET(the_url,
+         omit_token_if(grepl("public", the_url)),
+         if (interactive() && ddd$progress && verbose) httr::progress() else NULL) %>%
     httr::stop_for_status()
   rc <- content_as_xml_UTF8(req)
   ns <- xml2::xml_ns_rename(xml2::xml_ns(rc), d1 = "feed")
