@@ -40,9 +40,13 @@ cf <- gs_read_cellfeed(gs_ff())
 cf_printme <- cf %>%
   arrange(col, row) %>%
   select(cell, value, input_value, numeric_value)
-knitr::kable(cf_printme %>%
-               purrr::dmap_if(purrr::is_character,
-                              ~gsub('$', '\\$', .x, fixed = TRUE)))
+## work with purrr v0.2.2 but avoid deprecation warning with v0.2.2.1
+## modify_if() is ideal but not in v0.2.2
+cf_printme[] <- cf_printme %>%
+  purrr::map(~ if(purrr::is_character(.x)) {
+    gsub('$', '\\$', .x, fixed = TRUE)
+  } else .x)
+knitr::kable(cf_printme)
 
 ## ------------------------------------------------------------------------
 cf %>%
