@@ -12,7 +12,7 @@ test_that("Permissions for a spreadsheet are listed", {
   expect_equal(gs_perm_ls(new_ss)$role, "owner")
 
   expect_is(gs_perm_ls(gap_ss), "tbl_df")
-  expect_more_than(gs_perm_ls(gap_ss) %>% nrow(), 1L)
+  expect_gt(gs_perm_ls(gap_ss) %>% nrow(), 1L)
   expect_equal(gs_perm_ls(gap_ss, "anyone")$role, "reader")
 
 })
